@@ -17,7 +17,7 @@ This class use the full size of your terminal
 
 ## no critic (ProhibitExcessComplexity)
 
-our $VERSION = "4.099_001";
+our $VERSION = "4.099_002";
 
 use Getopt::Long::Descriptive;
 use Module::Runtime qw(use_module);
@@ -97,8 +97,8 @@ sub sub_commands_text {
     }
     return if !@$sub_commands;
     return "",
-        $self->__("SUB COMMANDS AVAILABLE: ") . join( ', ', @$sub_commands ),
-        "";
+        $self->__("SUB COMMANDS AVAILABLE: ")
+        . join( ', ', map { $_->{name} } @$sub_commands ), "";
 }
 
 =head2 text
@@ -223,8 +223,8 @@ sub option_help {
             "    ",
             "        ",
             defined $opt_data->{long_doc}
-            ? $opt_data->{long_doc}
-            : $opt->{desc}
+            ? $self->__( $opt_data->{long_doc} )
+            : $self->__( $opt->{desc} )
             );
     }
 
@@ -317,14 +317,25 @@ sub option_pod {
         push @man, "=head1 AVAILABLE SUB COMMANDS";
         push @man, "=over";
         for my $sub_command (@$sub_commands) {
+            if ($sub_command->{command}->can("_options_config")
+                && defined(
+                    my $desc
+                        = { $sub_command->{command}->_options_config }
+                        ->{description}
+                )
+                )
+            {
+                push @man, "=item B<" . $sub_command->{name} . "> : " . $desc;
+            }
+            else {
+                push @man, "=item B<" . $sub_command->{name} . "> :";
+            }
+
             push @man,
-                (
-                "=item B<" . $sub_command . "> :",
-                $prog_name . " "
-                    . $sub_command
-                    . " [-h] ["
-                    . $self->__("long options ...") . "]"
-                );
+                  $prog_name . " "
+                . $sub_command->{name}
+                . " [-h] ["
+                . $self->__("long options ...") . "]";
         }
         push @man, "=back";
     }
